{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (inputs.output_filename == \"\"){ return inputs.file_a.basename; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedtools2:v2.26.0"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-c"
                    },
                    "doc": "For each entry in A, report the number of hits in B. Reports 0 for A entries that have no overlap with B",
                    "id": "#bedtools-intersect.cwl/count"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-a"
                    },
                    "doc": "BAM/BED/GFF/VCF file A. Each feature in A is compared to B in search of overlaps",
                    "id": "#bedtools-intersect.cwl/file_a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-b"
                    },
                    "doc": "BAM/BED/GFF/VCF file B. Each feature in A is compared to B in search of overlaps",
                    "id": "#bedtools-intersect.cwl/file_b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-v"
                    },
                    "doc": "Only report those entries in A that have _no overlaps_ with B",
                    "id": "#bedtools-intersect.cwl/no_overlaps"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "",
                    "doc": "Output file name",
                    "id": "#bedtools-intersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-u"
                    },
                    "doc": "Write the original A entry _once_ if _any_ overlaps found in B",
                    "id": "#bedtools-intersect.cwl/report_from_a_once"
                }
            ],
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "stdout": "$(default_output_filename())",
            "doc": "Intersect features from A and B file. Only selected parameters are implemented.\n",
            "id": "#bedtools-intersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#bedtools-metadata.yaml",
                "http://schema.org/name": "bedtools",
                "http://schema.org/about": "A software suite for the comparison, manipulation and annotation of genomic features in browser extensible data (BED) and general feature format (GFF) format. BEDTools also supports the comparison of sequence alignments in BAM format to both BED and GFF features. The tools are extremely efficient and allow the user to compare large datasets (e.g. next-generation sequencing data) with both public and custom genome annotation tracks. BEDTools can be combined with one another as well as with standard UNIX commands, thus facilitating routine genomics tasks as well as pipelines that can quickly answer intricate questions of large genomic datasets.\n",
                "http://schema.org/url": "http://bedtools.readthedocs.org",
                "http://schema.org/codeRepository": "https://github.com/arq5x/bedtools2",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-2.0"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "2.26.0",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/publication": [
                    {
                        "class": "http://schema.org/ScholarlyArticle",
                        "id": "#bedtools-metadata.yaml/10.1093/bioinformatics/btq033",
                        "datePublished": "28 January 2010",
                        "http://schema.org/name": "BEDTools: a flexible suite of utilities for comparing genomic features",
                        "http://schema.org/author": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron R. Quinlan"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Ira M. Hall"
                            }
                        ],
                        "http://schema.org/url": "https://academic.oup.com/bioinformatics/article-lookup/doi/10.1093/bioinformatics/btq033"
                    }
                ],
                "http://schema.org/discussionUrl": [
                    "https://github.com/arq5x/bedtools2/issues",
                    "https://groups.google.com/forum/#!forum/bedtools-discuss"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "University of Utah",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Aaron Quinlan",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Neil Kindlon",
                                "http://schema.org/description": "Main author"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "bedtools-intersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bedtools-intersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:   bedtools intersect [OPTIONS] -a <bed/gff/vcf/bam> -b <bed/gff/vcf/bam>\n\n  Note: -b may be followed with multiple databases and/or \n  wildcard (*) character(s). \nOptions: \n  -wa\tWrite the original entry in A for each overlap.\n\n  -wb\tWrite the original entry in B for each overlap.\n    - Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n\n  -loj\tPerform a \"left outer join\". That is, for each feature in A\n    report each overlap with B.  If no overlaps are found, \n    report a NULL feature for B.\n\n  -wo\tWrite the original A and B entries plus the number of base\n    pairs of overlap between the two features.\n    - Overlaps restricted by -f and -r.\n      Only A features with overlap are reported.\n\n  -wao\tWrite the original A and B entries plus the number of base\n    pairs of overlap between the two features.\n    - Overlapping features restricted by -f and -r.\n      However, A features w/o overlap are also reported\n      with a NULL B feature and overlap = 0.\n\n  -u\tWrite the original A entry _once_ if _any_ overlaps found in B.\n    - In other words, just report the fact >=1 hit was found.\n    - Overlaps restricted by -f and -r.\n\n  -c\tFor each entry in A, report the number of overlaps with B.\n    - Reports 0 for A entries that have no overlap with B.\n    - Overlaps restricted by -f and -r.\n\n  -v\tOnly report those entries in A that have _no overlaps_ with B.\n    - Similar to \"grep -v\" (an homage).\n\n  -ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n  -s\tRequire same strandedness.  That is, only report hits in B\n    that overlap A on the _same_ strand.\n    - By default, overlaps are reported without respect to strand.\n\n  -S\tRequire different strandedness.  That is, only report hits in B\n    that overlap A on the _opposite_ strand.\n    - By default, overlaps are reported without respect to strand.\n\n  -f\tMinimum overlap required as a fraction of A.\n    - Default is 1E-9 (i.e., 1bp).\n    - FLOAT (e.g. 0.50)\n\n  -F\tMinimum overlap required as a fraction of B.\n    - Default is 1E-9 (i.e., 1bp).\n    - FLOAT (e.g. 0.50)\n\n  -r\tRequire that the fraction overlap be reciprocal for A AND B.\n    - In other words, if -f is 0.90 and -r is used, this requires\n      that B overlap 90% of A and A _also_ overlaps 90% of B.\n\n  -e\tRequire that the minimum fraction be satisfied for A OR B.\n    - In other words, if -e is used with -f 0.90 and -F 0.10 this requires\n      that either 90% of A is covered OR 10% of  B is covered.\n      Without -e, both fractions would have to be satisfied.\n\n  -split\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\n  -g\tProvide a genome file to enforce consistent chromosome sort order\n    across input files. Only applies when used with -sorted option.\n\n  -nonamecheck\tFor sorted data, don't throw an error if the file has different naming conventions\n      for the same chromosome. ex. \"chr1\" vs \"chr01\".\n\n  -sorted\tUse the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n\n  -names\tWhen using multiple databases, provide an alias for each that\n    will appear instead of a fileId when also printing the DB record.\n\n  -filenames\tWhen using multiple databases, show each complete filename\n      instead of a fileId when also printing the DB record.\n\n  -sortout\tWhen using multiple databases, sort the output DB hits\n      for each record.\n\n  -bed\tIf using BAM input, write output as BED.\n\n  -header\tPrint the header from the A file prior to results.\n\n  -nobuf\tDisable buffered output. Using this option will cause each line\n    of output to be printed as it is generated, rather than saved\n    in a buffer. This will make printing large output files \n    noticeably slower, but can be useful in conjunction with\n    other software tools and scripts that need to process one\n    line of bedtools output at a time.\n\n  -iobuf\tSpecify amount of memory to use for input buffer.\n    Takes an integer argument. Optional suffixes K/M/G supported.\n    Note: currently has no effect with compressed files.\n\nNotes: \n  (1) When a BAM file is used for the A file, the alignment is retained if overlaps exist,\n  and exlcuded if an overlap cannot be found.  If multiple overlaps exist, they are not\n  reported, as we are only testing for one or more overlaps.",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "doc": "Intersected BED file",
                    "id": "#bedtools-intersect.cwl/intersected_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (inputs.output_filename == \"\"){ return inputs.bed_file.basename; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/bedtools2:v2.26.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-i"
                    },
                    "doc": "The input BED file must be sorted by chrom, then start",
                    "id": "#bedtools-merge.cwl/bed_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-d"
                    },
                    "doc": "Maximum distance between features to be merged",
                    "id": "#bedtools-merge.cwl/max_distance"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "",
                    "doc": "Output file name",
                    "id": "#bedtools-merge.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "doc": "Merged BED file",
                    "id": "#bedtools-merge.cwl/merged_bed_file"
                }
            ],
            "baseCommand": [
                "bedtools",
                "merge"
            ],
            "stdout": "$(default_output_filename())",
            "doc": "Merges features from BED file. Only selected parameters are implemented.\n",
            "id": "#bedtools-merge.cwl",
            "http://schema.org/mainEntity": {
                "$import": "#bedtools-metadata.yaml"
            },
            "http://schema.org/name": "bedtools-merge",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/bedtools-merge.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:   bedtools merge [OPTIONS] -i <bed/gff/vcf>\n\nOptions: \n  -s\tForce strandedness.  That is, only merge features\n    that are on the same strand.\n    - By default, merging is done without respect to strand.\n\n  -S\tForce merge for one specific strand only.\n    Follow with + or - to force merge from only\n    the forward or reverse strand, respectively.\n    - By default, merging is done without respect to strand.\n\n  -d\tMaximum distance between features allowed for features\n    to be merged.\n    - Def. 0. That is, overlapping & book-ended features are merged.\n    - (INTEGER)\n    - Note: negative values enforce the number of b.p. required for overlap.\n\n  -c\tSpecify columns from the B file to map onto intervals in A.\n    Default: 5.\n    Multiple columns can be specified in a comma-delimited list.\n\n  -o\tSpecify the operation that should be applied to -c.\n    Valid operations:\n        sum, min, max, absmin, absmax,\n        mean, median, mode, antimode\n        stdev, sstdev\n        collapse (i.e., print a delimited list (duplicates allowed)), \n        distinct (i.e., print a delimited list (NO duplicates allowed)), \n        distinct_sort_num (as distinct, sorted numerically, ascending),\n        distinct_sort_num_desc (as distinct, sorted numerically, desscending),\n        distinct_only (delimited list of only unique values),\n        count\n        count_distinct (i.e., a count of the unique values in the column), \n        first (i.e., just the first value in the column), \n        last (i.e., just the last value in the column), \n    Default: sum\n    Multiple operations can be specified in a comma-delimited list.\n\n    If there is only column, but multiple operations, all operations will be\n    applied on that column. Likewise, if there is only one operation, but\n    multiple columns, that operation will be applied to all columns.\n    Otherwise, the number of columns must match the the number of operations,\n    and will be applied in respective order.\n    E.g., \"-c 5,4,6 -o sum,mean,count\" will give the sum of column 5,\n    the mean of column 4, and the count of column 6.\n    The order of output columns will match the ordering given in the command.\n\n\n  -delim\tSpecify a custom delimiter for the collapse operations.\n    - Example: -delim \"|\"\n    - Default: \",\".\n\n  -prec\tSets the decimal precision for output (Default: 5)\n\n  -bed\tIf using BAM input, write output as BED.\n\n  -header\tPrint the header from the A file prior to results.\n\n  -nobuf\tDisable buffered output. Using this option will cause each line\n    of output to be printed as it is generated, rather than saved\n    in a buffer. This will make printing large output files \n    noticeably slower, but can be useful in conjunction with\n    other software tools and scripts that need to process one\n    line of bedtools output at a time.\n\n  -iobuf\tSpecify amount of memory to use for input buffer.\n    Takes an integer argument. Optional suffixes K/M/G supported.\n    Note: currently has no effect with compressed files.\n\nNotes: \n  (1) The input file (-i) file must be sorted by chrom, then start.\n"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename == \"\"){ var ext = \".tar.gz\"; var root = inputs.target_regions_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.target_regions_file.basename+ext:root+ext; } else { return inputs.output_filename; } };"
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return  [\n            {\n              \"entry\": inputs.genome_fasta_file,\n              \"entryname\": inputs.genome_fasta_file.basename,\n              \"writable\": true\n            }\n          ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/homer:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-mask"
                    },
                    "doc": "Use the repeat-masked sequence (all repeats will be masked by N)\n",
                    "id": "#homer-find-motifs-genome.cwl/apply_mask_on_genome"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-bg"
                    },
                    "doc": "Background regions BED file. [chr] [start] [end] [unique ID] [dummy] [strand]\n",
                    "id": "#homer-find-motifs-genome.cwl/background_regions_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-chopify"
                    },
                    "doc": "Chop up large background regions to the avg size of target regions\n",
                    "id": "#homer-find-motifs-genome.cwl/chopify_background_regions"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 19,
                        "prefix": "-cpg"
                    },
                    "doc": "Use CpG% instead of GC% for sequence content normalization\n",
                    "id": "#homer-find-motifs-genome.cwl/cpg_normalization"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 18,
                        "prefix": "-gc"
                    },
                    "doc": "Use GC% for sequence content normalization, now the default\n",
                    "id": "#homer-find-motifs-genome.cwl/gc_normalization"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Reference genome FASTA file. Includes all chromosomes in a single file\n",
                    "id": "#homer-find-motifs-genome.cwl/genome_fasta_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-len"
                    },
                    "doc": "<#>[,<#>,<#>...] - motif length\nDefault=8,10,12\n",
                    "id": "#homer-find-motifs-genome.cwl/motif_length"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#homer-find-motifs-genome.cwl/motifs_db/motifs",
                            "symbols": [
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/vertebrates",
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/insects",
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/worms",
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/plants",
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/yeast",
                                "#homer-find-motifs-genome.cwl/motifs_db/motifs/all"
                            ]
                        }
                    ],
                    "default": "vertebrates",
                    "inputBinding": {
                        "position": 17,
                        "prefix": "-mset"
                    },
                    "doc": "Set motifs DB to check against. Default: vertebrates\n",
                    "id": "#homer-find-motifs-genome.cwl/motifs_db"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "valueFrom": "$(get_output_filename())"
                    },
                    "default": "",
                    "doc": "Name for compressed output folder to keep all the results\n",
                    "id": "#homer-find-motifs-genome.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\necho findMotifsGenome.pl $0 $1 homer_results ${@:3}\nfindMotifsGenome.pl $0 $1 homer_results ${@:3}\necho tar -czf $2 homer_results\ntar -czf $2 homer_results\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to run findMotifsGenome.pl and to compress results to tar.gz\n",
                    "id": "#homer-find-motifs-genome.cwl/script"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-size"
                    },
                    "doc": "Fragment size to use for motif finding.\n<#> - i.e. -size 300 will get sequences from -150 to +150 relative from center\n<#,#> - i.e. -size -100,50 will get sequences from -100 to +50 relative from center\ngiven - will use the exact regions you give it.\nDefault=200\n",
                    "id": "#homer-find-motifs-genome.cwl/search_size"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "prefix": "-nomotif"
                    },
                    "doc": "Don't search for de novo motif enrichment\n",
                    "id": "#homer-find-motifs-genome.cwl/skip_denovo"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 16,
                        "prefix": "-noknown"
                    },
                    "doc": "Don't search for known motif enrichment\n",
                    "id": "#homer-find-motifs-genome.cwl/skip_known"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 20,
                        "prefix": "-noweight"
                    },
                    "doc": "Skip CG correction\n",
                    "id": "#homer-find-motifs-genome.cwl/skip_normalization"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Target regions BED file to be scanned for motifs. [chr] [start] [end] [unique ID] [dummy] [strand]\n",
                    "id": "#homer-find-motifs-genome.cwl/target_regions_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 21,
                        "prefix": "-p"
                    },
                    "doc": "Number of threads to use\n",
                    "id": "#homer-find-motifs-genome.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "-h"
                    },
                    "doc": "Use hypergeometric for p-values, instead of default binomial.\nUsefull if the number of background sequences is smaller than target sequences\n",
                    "id": "#homer-find-motifs-genome.cwl/use_hypergeometric"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    },
                    "doc": "Compressed folder with all generated results\n",
                    "id": "#homer-find-motifs-genome.cwl/compressed_results_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "homer_results/homerResults.html"
                    },
                    "doc": "de novo motifs html file\n",
                    "id": "#homer-find-motifs-genome.cwl/denovo_motifs"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "homer_results/knownResults.html"
                    },
                    "doc": "Known motifs html file\n",
                    "id": "#homer-find-motifs-genome.cwl/known_motifs"
                },
                {
                    "type": "File",
                    "id": "#homer-find-motifs-genome.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "homer_find_motifs_genome_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#homer-find-motifs-genome.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "homer_find_motifs_genome_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "stdout": "homer_find_motifs_genome_stdout.log",
            "stderr": "homer_find_motifs_genome_stderr.log",
            "doc": "HOMER contains a novel motif discovery algorithm that was designed for regulatory element analysis\nin genomics applications (DNA only, no protein).  It is a differential motif discovery algorithm,\nwhich means that it takes two sets of sequences and tries to identify the regulatory elements that\nare specifically enriched in on set relative to the other.  It uses ZOOPS scoring (zero or one\noccurrence per sequence) coupled with the hypergeometric enrichment calculations (or binomial) to\ndetermine motif enrichment. HOMER also tries its best to account for sequenced bias in the dataset.\nIt was designed with ChIP-Seq and promoter analysis in mind, but can be applied to pretty much any\nnucleic acids motif finding problem.\n\nOnly selected parameters are implemented.\n",
            "id": "#homer-find-motifs-genome.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#homer-metadata.yaml",
                "http://schema.org/name": "Homer",
                "http://schema.org/about": "HOMER (Hypergeometric Optimization of Motif EnRichment)"
            },
            "http://schema.org/name": "homer-find-motifs",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/homer-find-motifs-genome.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage: findMotifsGenome.pl <pos file> <genome> <output directory> [additional options]\nExample: findMotifsGenome.pl peaks.txt mm8r peakAnalysis -size 200 -len 8\n\nPossible Genomes:\n    -- or --\n  Custom: provide the path to genome FASTA files (directory or single file)\n    Heads up: will create the directory \"preparsed/\" in same location.\n\nBasic options:\n  -mask (mask repeats/lower case sequence, can also add 'r' to genome, i.e. mm9r)\n  -bg <background position file> (genomic positions to be used as background, default=automatic)\n    removes background positions overlapping with target positions\n    -chopify (chop up large background regions to the avg size of target regions)\n  -len <#>[,<#>,<#>...] (motif length, default=8,10,12) [NOTE: values greater 12 may cause the program\n    to run out of memory - in these cases decrease the number of sequences analyzed (-N),\n    or try analyzing shorter sequence regions (i.e. -size 100)]\n  -size <#> (fragment size to use for motif finding, default=200)\n    -size <#,#> (i.e. -size -100,50 will get sequences from -100 to +50 relative from center)\n    -size given (uses the exact regions you give it)\n  -S <#> (Number of motifs to optimize, default: 25)\n  -mis <#> (global optimization: searches for strings with # mismatches, default: 2)\n  -norevopp (don't search reverse strand for motifs)\n  -nomotif (don't search for de novo motif enrichment)\n  -rna (output RNA motif logos and compare to RNA motif database, automatically sets -norevopp)\n\nScanning sequence for motifs\n  -find <motif file> (This will cause the program to only scan for motifs)\n\nKnown Motif Options/Visualization\n  -mset <vertebrates|insects|worms|plants|yeast|all> (check against motif collects, default: auto)\n  -basic (just visualize de novo motifs, don't check similarity with known motifs)\n  -bits (scale sequence logos by information content, default: doesn't scale)\n  -nocheck (don't search for de novo vs. known motif similarity)\n  -mcheck <motif file> (known motifs to check against de novo motifs,\n  -noknown (don't search for known motif enrichment, default: -known)\n  -mknown <motif file> (known motifs to check for enrichment,\n  -nofacts (omit humor)\n  -seqlogo (use weblogo/seqlogo/ghostscript to generate logos, default uses SVG now)\n\nSequence normalization options:\n  -gc (use GC% for sequence content normalization, now the default)\n  -cpg (use CpG% instead of GC% for sequence content normalization)\n  -noweight (no CG correction)\n  Also -nlen <#>, -olen <#>, see homer2 section below.\n\nAdvanced options:\n  -h (use hypergeometric for p-values, binomial is default)\n  -N <#> (Number of sequences to use for motif finding, default=max(50k, 2x input)\n  -local <#> (use local background, # of equal size regions around peaks to use i.e. 2)\n  -redundant <#> (Remove redundant sequences matching greater than # percent, i.e. -redundant 0.5)\n  -maxN <#> (maximum percentage of N's in sequence to consider for motif finding, default: 0.7)\n  -maskMotif <motif file1> [motif file 2]... (motifs to mask before motif finding)\n  -opt <motif file1> [motif file 2]... (motifs to optimize or change length of)\n  -rand (randomize target and background sequences labels)\n  -ref <peak file> (use file for target and background - first argument is list of peak ids for targets)\n  -oligo (perform analysis of individual oligo enrichment)\n  -dumpFasta (Dump fasta files for target and background sequences for use with other programs)\n  -preparse (force new background files to be created)\n  -preparsedDir <directory> (location to search for preparsed file and/or place new files)\n  -keepFiles (keep temporary files)\n  -fdr <#> (Calculate empirical FDR for de novo discovery #=number of randomizations)\n\nhomer2 specific options:\n  -homer2 (use homer2 instead of original homer, default)\n  -nlen <#> (length of lower-order oligos to normalize in background, default: -nlen 3)\n    -nmax <#> (Max normalization iterations, default: 160)\n    -neutral (weight sequences to neutral frequencies, i.e. 25%, 6.25%, etc.)\n  -olen <#> (lower-order oligo normalization for oligo table, use if -nlen isn't working well)\n  -p <#> (Number of processors to use, default: 1)\n  -e <#> (Maximum expected motif instance per bp in random sequence, default: 0.01)\n  -cache <#> (size in MB for statistics cache, default: 500)\n  -quickMask (skip full masking after finding motifs, similar to original homer)\n  -minlp <#> (stop looking for motifs when seed logp score gets above #, default: -10)\n\nOriginal homer specific options:\n  -homer1 (to force the use of the original homer)\n  -depth [low|med|high|allnight] (time spent on local optimization default: med)\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "genome_indices": [
                    "genome-indices.cwl"
                ],
                "regions_a": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "regions_b": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "label": "Mask all repeats with N",
                    "doc": "Use the repeat-masked sequence (all repeats will be masked by N)",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/apply_mask_on_genome"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Chop up large background regions to the avg size of target regions",
                    "doc": "Chop up large background regions to the avg size of target regions",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/chopify_background_regions"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Target regions ranges. Headerless BED file with minimum [chrom start end name dummy strand] columns. Optionally, CSV",
                    "doc": "Target regions ranges. Headerless BED file with minimum [chrom start end unique_id dummy strand] columns. Optionally, CSV",
                    "id": "#main/diff_regions_file_a"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Background regions ranges. Headerless BED file with minimum [chrom start end name dummy strand] columns. Optionally, CSV",
                    "doc": "Background regions ranges. Headerless BED file with minimum [chrom start end unique_id dummy strand] columns. Optionally, CSV",
                    "id": "#main/diff_regions_file_b"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "label": "Reference genome FASTA file",
                    "doc": "Reference genome FASTA file. Includes all chromosomes in a single file",
                    "sd:upstreamSource": "genome_indices/fasta_output",
                    "id": "#main/genome_fasta_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "0",
                    "label": "Min signalValue for peaks selected as target regions",
                    "doc": "Discard all peaks from narrowPeak file of target regions with signalValue smaller than this threshold",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/min_signal_regions_a"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "0",
                    "label": "Min signalValue for peaks selected as background regions",
                    "doc": "Discard all peaks from narrowPeak file of background regions with signalValue smaller than this threshold",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/min_signal_regions_b"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "8,10,12",
                    "label": "Motif length(s) for de novo motif discovery",
                    "doc": "<#>[,<#>,<#>...] - motif length. Default=8,10,12",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/motif_length"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/motifs_db/vertebrates",
                                "#main/motifs_db/insects",
                                "#main/motifs_db/worms",
                                "#main/motifs_db/plants",
                                "#main/motifs_db/yeast",
                                "#main/motifs_db/all"
                            ]
                        }
                    ],
                    "default": "vertebrates",
                    "label": "Set motifs DB to check against",
                    "doc": "Set motifs DB to check against",
                    "id": "#main/motifs_db"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3613",
                    "label": "Samples to select target regions from",
                    "doc": "Narrow peak files to select target regions from",
                    "sd:upstreamSource": "regions_a/macs2_narrow_peaks",
                    "sd:localLabel": true,
                    "id": "#main/regions_files_a"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3613",
                    "label": "Samples to select background regions from",
                    "doc": "Narrow peak files to select background regions from",
                    "sd:upstreamSource": "regions_b/macs2_narrow_peaks",
                    "sd:localLabel": true,
                    "id": "#main/regions_files_b"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "200",
                    "label": "Fragment size to use for motif finding. Can be set as <#> or <#,#>",
                    "doc": "Fragment size to use for motif finding.\n<#> - i.e. -size 300 will get sequences from -150 to +150 relative from center\n<#,#> - i.e. -size -100,50 will get sequences from -100 to +50 relative from center\ngiven - will use the exact regions you give it.\nDefault=200\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/search_size"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "label": "Skip de novo motif enrichment",
                    "doc": "Skip de novo motif enrichment",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/skip_denovo"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Skip known motif enrichment",
                    "doc": "Skip known motif enrichment",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/skip_known"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Threads number",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Use hypergeometric for p-values, instead of default binomial. Usefull if the number of background sequences is smaller than target sequences",
                    "doc": "Use hypergeometric for p-values, instead of default binomial. Usefull if the number of background sequences is smaller than target sequences",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/use_hypergeometric"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2331",
                    "outputSource": "#main/find_motifs/denovo_motifs",
                    "label": "de novo motifs",
                    "doc": "de novo motifs html file",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/homer_denovo_motifs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/find_motifs/compressed_results_folder",
                    "label": "Compressed file with Homer motifs",
                    "doc": "Homer motifs",
                    "id": "#main/homer_found_motifs"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_2331",
                    "outputSource": "#main/find_motifs/known_motifs",
                    "label": "Known motifs",
                    "doc": "Known motifs html file",
                    "sd:visualPlugins": [
                        {
                            "linkList": {
                                "tab": "Overview",
                                "target": "_blank"
                            }
                        }
                    ],
                    "id": "#main/homer_known_motifs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/find_motifs/stderr_log",
                    "label": "Homer stderr log",
                    "doc": "Homer stderr log",
                    "id": "#main/homer_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/find_motifs/stdout_log",
                    "label": "Homer stdout log",
                    "doc": "Homer stdout log",
                    "id": "#main/homer_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/regions_files_a",
                            "id": "#main/concat_dedup_and_sort_regions_a/input_file"
                        },
                        {
                            "source": "#main/min_signal_regions_a",
                            "id": "#main/concat_dedup_and_sort_regions_a/param"
                        },
                        {
                            "default": "set -- \"$0\" \"$@\"\necho \"files: \" \"${@:1:$#-1}\"\nTH=\"${@: -1}\"\necho \"Threashold\" \"$TH\"\ncat \"${@:1:$#-1}\" | tr -d '\\r' | tr \",\" \"\\t\" | awk NF | awk -v th=$TH '{if ($7 >= th) print $0}' | sort -u -k1,1 -k2,2n -k3,3n | awk '{print $1\"\\t\"$2\"\\t\"$3\"\\tp\"NR\"\\t\"$5\"\\t\"$6}' > concatenated_sorted_unique_regions_from_a.bed\n",
                            "id": "#main/concat_dedup_and_sort_regions_a/script"
                        }
                    ],
                    "out": [
                        "#main/concat_dedup_and_sort_regions_a/output_file"
                    ],
                    "id": "#main/concat_dedup_and_sort_regions_a"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/regions_files_b",
                            "id": "#main/concat_dedup_and_sort_regions_b/input_file"
                        },
                        {
                            "source": "#main/min_signal_regions_b",
                            "id": "#main/concat_dedup_and_sort_regions_b/param"
                        },
                        {
                            "default": "set -- \"$0\" \"$@\"\necho \"files: \" \"${@:1:$#-1}\"\nTH=\"${@: -1}\"\necho \"Threashold\" \"$TH\"\ncat \"${@:1:$#-1}\" | tr -d '\\r' | tr \",\" \"\\t\" | awk NF | awk -v th=$TH '{if ($7 >= th) print $0}' | sort -u -k1,1 -k2,2n -k3,3n | awk '{print $1\"\\t\"$2\"\\t\"$3\"\\tp\"NR\"\\t\"$5\"\\t\"$6}' > concatenated_sorted_unique_regions_from_b.bed\n",
                            "id": "#main/concat_dedup_and_sort_regions_b/script"
                        }
                    ],
                    "out": [
                        "#main/concat_dedup_and_sort_regions_b/output_file"
                    ],
                    "id": "#main/concat_dedup_and_sort_regions_b"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/diff_regions_file_a",
                            "id": "#main/dedup_and_sort_diff_regions_a/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr -d '\\r' | tr \",\" \"\\t\" | awk NF | sort -u -k1,1 -k2,2n -k3,3n | awk '{print $1\"\\t\"$2\"\\t\"$3\"\\tp\"NR\"\\t\"$5\"\\t\"$6}' > sorted_unique_diff_regions_from_a.bed\n",
                            "id": "#main/dedup_and_sort_diff_regions_a/script"
                        }
                    ],
                    "out": [
                        "#main/dedup_and_sort_diff_regions_a/output_file"
                    ],
                    "id": "#main/dedup_and_sort_diff_regions_a"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/diff_regions_file_b",
                            "id": "#main/dedup_and_sort_diff_regions_b/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr -d '\\r' | tr \",\" \"\\t\" | awk NF | sort -u -k1,1 -k2,2n -k3,3n | awk '{print $1\"\\t\"$2\"\\t\"$3\"\\tp\"NR\"\\t\"$5\"\\t\"$6}' > sorted_unique_diff_regions_from_b.bed\n",
                            "id": "#main/dedup_and_sort_diff_regions_b/script"
                        }
                    ],
                    "out": [
                        "#main/dedup_and_sort_diff_regions_b/output_file"
                    ],
                    "id": "#main/dedup_and_sort_diff_regions_b"
                },
                {
                    "run": "#homer-find-motifs-genome.cwl",
                    "in": [
                        {
                            "source": "#main/apply_mask_on_genome",
                            "id": "#main/find_motifs/apply_mask_on_genome"
                        },
                        {
                            "source": "#main/merge_overlapped_with_diff_regions_b/merged_bed_file",
                            "id": "#main/find_motifs/background_regions_file"
                        },
                        {
                            "source": "#main/chopify_background_regions",
                            "id": "#main/find_motifs/chopify_background_regions"
                        },
                        {
                            "source": "#main/genome_fasta_file",
                            "id": "#main/find_motifs/genome_fasta_file"
                        },
                        {
                            "source": "#main/motif_length",
                            "id": "#main/find_motifs/motif_length"
                        },
                        {
                            "source": "#main/motifs_db",
                            "id": "#main/find_motifs/motifs_db"
                        },
                        {
                            "source": "#main/search_size",
                            "id": "#main/find_motifs/search_size"
                        },
                        {
                            "source": "#main/skip_denovo",
                            "id": "#main/find_motifs/skip_denovo"
                        },
                        {
                            "source": "#main/skip_known",
                            "id": "#main/find_motifs/skip_known"
                        },
                        {
                            "source": "#main/merge_overlapped_with_diff_regions_a/merged_bed_file",
                            "id": "#main/find_motifs/target_regions_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/find_motifs/threads"
                        },
                        {
                            "source": "#main/use_hypergeometric",
                            "id": "#main/find_motifs/use_hypergeometric"
                        }
                    ],
                    "out": [
                        "#main/find_motifs/compressed_results_folder",
                        "#main/find_motifs/known_motifs",
                        "#main/find_motifs/denovo_motifs",
                        "#main/find_motifs/stdout_log",
                        "#main/find_motifs/stderr_log"
                    ],
                    "id": "#main/find_motifs"
                },
                {
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#main/concat_dedup_and_sort_regions_a/output_file",
                            "id": "#main/get_overlapped_with_diff_regions_a/file_a"
                        },
                        {
                            "source": "#main/dedup_and_sort_diff_regions_a/output_file",
                            "id": "#main/get_overlapped_with_diff_regions_a/file_b"
                        },
                        {
                            "default": "concatenated_sorted_unique_regions_from_a_overlapped_with_diff.bed",
                            "id": "#main/get_overlapped_with_diff_regions_a/output_filename"
                        },
                        {
                            "default": true,
                            "id": "#main/get_overlapped_with_diff_regions_a/report_from_a_once"
                        }
                    ],
                    "out": [
                        "#main/get_overlapped_with_diff_regions_a/intersected_file"
                    ],
                    "id": "#main/get_overlapped_with_diff_regions_a"
                },
                {
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#main/concat_dedup_and_sort_regions_b/output_file",
                            "id": "#main/get_overlapped_with_diff_regions_b/file_a"
                        },
                        {
                            "source": "#main/dedup_and_sort_diff_regions_b/output_file",
                            "id": "#main/get_overlapped_with_diff_regions_b/file_b"
                        },
                        {
                            "default": "concatenated_sorted_unique_regions_from_b_overlapped_with_diff.bed",
                            "id": "#main/get_overlapped_with_diff_regions_b/output_filename"
                        },
                        {
                            "default": true,
                            "id": "#main/get_overlapped_with_diff_regions_b/report_from_a_once"
                        }
                    ],
                    "out": [
                        "#main/get_overlapped_with_diff_regions_b/intersected_file"
                    ],
                    "id": "#main/get_overlapped_with_diff_regions_b"
                },
                {
                    "run": "#bedtools-merge.cwl",
                    "in": [
                        {
                            "source": "#main/get_overlapped_with_diff_regions_a/intersected_file",
                            "id": "#main/merge_overlapped_with_diff_regions_a/bed_file"
                        },
                        {
                            "default": "merged_overlapped_with_diff_concatenated_sorted_unique_regions_from_a.bed",
                            "id": "#main/merge_overlapped_with_diff_regions_a/output_filename"
                        }
                    ],
                    "out": [
                        "#main/merge_overlapped_with_diff_regions_a/merged_bed_file"
                    ],
                    "id": "#main/merge_overlapped_with_diff_regions_a"
                },
                {
                    "run": "#bedtools-merge.cwl",
                    "in": [
                        {
                            "source": "#main/get_overlapped_with_diff_regions_b/intersected_file",
                            "id": "#main/merge_overlapped_with_diff_regions_b/bed_file"
                        },
                        {
                            "default": "merged_overlapped_with_diff_concatenated_sorted_unique_regions_from_b.bed",
                            "id": "#main/merge_overlapped_with_diff_regions_b/output_filename"
                        }
                    ],
                    "out": [
                        "#main/merge_overlapped_with_diff_regions_b/merged_bed_file"
                    ],
                    "id": "#main/merge_overlapped_with_diff_regions_b"
                }
            ],
            "label": "Motif Finding with HOMER with target and background regions from peaks",
            "doc": "Motif Finding with HOMER with target and background regions from peaks\n---------------------------------------------------\n\nHOMER contains a novel motif discovery algorithm that was designed for regulatory element analysis\nin genomics applications (DNA only, no protein). It is a differential motif discovery algorithm,\nwhich means that it takes two sets of sequences and tries to identify the regulatory elements that\nare specifically enriched in on set relative to the other. It uses ZOOPS scoring (zero or one\noccurrence per sequence) coupled with the hypergeometric enrichment calculations (or binomial) to\ndetermine motif enrichment. HOMER also tries its best to account for sequenced bias in the dataset.\nIt was designed with ChIP-Seq and promoter analysis in mind, but can be applied to pretty much any\nnucleic acids motif finding problem.\n\nFor more information please refer to:\n-------------------------------------\n[Official documentation](http://homer.ucsd.edu/homer/motif/)",
            "id": "#main",
            "http://schema.org/name": "Motif Finding with HOMER with target and background regions from peaks",
            "http://schema.org/alternateName": "Motif Finding with HOMER with target and background regions from peaks",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/homer-motif-analysis-peak.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
